@@ -14,7 +14,7 @@
 #' @export
 eq5d5l <- function(scores, country="England") {
   
-  if(!all(names(scores) %in% .getDimensionNames()))
+  if(!all(.getDimensionNames() %in% names(scores)))
     stop("Unable to identify EQ-5D dimensions in scores.")
   
   if(!all(scores %in% 1:5))
@@ -22,7 +22,7 @@ eq5d5l <- function(scores, country="England") {
   
   survey <- get("VT")
   
-  if(!country %in% colnames(survey))
+  if(is.null(country) || !country %in% colnames(survey))
     stop(paste("Country must be one of:", paste(colnames(survey), collapse=", ")))
   
   survey <- survey[country]
@@ -32,7 +32,8 @@ eq5d5l <- function(scores, country="England") {
               .minOneGreaterThan1(scores,survey),
               .level4Or5(scores, survey),
               .num45sq(scores, survey),
-              .N4(scores,survey))
+              .N4(scores,survey),
+              .N5(scores,survey))
 
     return(round(sum(values, na.rm = TRUE), digits=3))
 }
@@ -71,3 +72,12 @@ eq5d5l <- function(scores, country="England") {
     return(value)
   }
 }
+
+.N5 <- function(scores, survey) {
+  ##at least one mobility, care, activity, pain, anxiety == 5
+  if(any(scores == 5) && !is.na(survey["N5",])) {
+    value <- survey["N5",]
+    names(value) <- "N5"
+    return(value)
+  }
+}
